@@ -81,7 +81,27 @@ class Robot:
     def send_qq_music_sharing(self, name, accept_wxid):
         r = requests.get(f"http://114.116.54.227:9999/qqmusic/?name={name}")
         jsondata = r.json()
-        author = jsondata["author'"]
+        author = jsondata["author"]
+        jumpUrl = jsondata["link"]
+        musicUrl = jsondata["url"]
+        imageUrl = jsondata["pic"]
+        type_ = "Q0014"
+        data_ = {"type": f"{type_}",
+                 "data": {"wxid": f"{accept_wxid}",
+                          "name": f"{name}",
+                          "author": f"{author}",
+                          "app": "wx5aa333606550dfd5",
+                          "jumpUrl": f"{jumpUrl}",
+                          "musicUrl": f"{musicUrl}",
+                          "imageUrl": f"{imageUrl}"},
+                 }
+
+        return self.post_(type_, data_)
+
+    def send_163_music_sharing(self, name, accept_wxid):
+        r = requests.get(f"http://114.116.54.227:9999/163music/?name={name}")
+        jsondata = r.json()
+        author = jsondata["author"]
         jumpUrl = jsondata["link"]
         musicUrl = jsondata["url"]
         imageUrl = jsondata["pic"]
